@@ -16,49 +16,86 @@ _ = Translator("UtilsChatFormatting", __file__)
 def error(text: str) -> str:
     """Get text prefixed with an error emoji.
 
+    Parameters
+    ----------
+    text : str
+        The text to be prefixed.
+
     Returns
     -------
     str
         The new message.
 
     """
-    return "\N{NO ENTRY SIGN} {}".format(text)
+    return f"\N{NO ENTRY SIGN} {text}"
 
 
 def warning(text: str) -> str:
     """Get text prefixed with a warning emoji.
 
+    Parameters
+    ----------
+    text : str
+        The text to be prefixed.
+
     Returns
     -------
     str
         The new message.
 
     """
-    return "\N{WARNING SIGN}\N{VARIATION SELECTOR-16} {}".format(text)
+    return f"\N{WARNING SIGN}\N{VARIATION SELECTOR-16} {text}"
 
 
 def info(text: str) -> str:
     """Get text prefixed with an info emoji.
 
+    Parameters
+    ----------
+    text : str
+        The text to be prefixed.
+
     Returns
     -------
     str
         The new message.
 
     """
-    return "\N{INFORMATION SOURCE}\N{VARIATION SELECTOR-16} {}".format(text)
+    return f"\N{INFORMATION SOURCE}\N{VARIATION SELECTOR-16} {text}"
+
+
+def success(text: str) -> str:
+    """Get text prefixed with a success emoji.
+
+    Parameters
+    ----------
+    text : str
+        The text to be prefixed.
+
+    Returns
+    -------
+    str
+        The new message.
+
+    """
+    return f"\N{WHITE HEAVY CHECK MARK} {text}"
 
 
 def question(text: str) -> str:
     """Get text prefixed with a question emoji.
 
+    Parameters
+    ----------
+    text : str
+        The text to be prefixed.
+
     Returns
     -------
     str
         The new message.
 
     """
-    return "\N{BLACK QUESTION MARK ORNAMENT}\N{VARIATION SELECTOR-16} {}".format(text)
+    return f"\N{BLACK QUESTION MARK ORNAMENT}\N{VARIATION SELECTOR-16} {text}"
 
 
 def bold(text: str, escape_formatting: bool = True) -> str:
@@ -79,8 +116,7 @@ def bold(text: str, escape_formatting: bool = True) -> str:
         The marked up text.
 
     """
-    text = escape(text, formatting=escape_formatting)
-    return "**{}**".format(text)
+    return f"**{escape(text, formatting=escape_formatting)}**"
 
 
 def box(text: str, lang: str = "") -> str:
@@ -99,8 +135,7 @@ def box(text: str, lang: str = "") -> str:
         The marked up text.
 
     """
-    ret = "```{}\n{}\n```".format(lang, text)
-    return ret
+    return f"```{lang}\n{text}\n```"
 
 
 def inline(text: str) -> str:
@@ -118,9 +153,9 @@ def inline(text: str) -> str:
 
     """
     if "`" in text:
-        return "``{}``".format(text)
+        return f"``{text}``"
     else:
-        return "`{}`".format(text)
+        return f"`{text}`"
 
 
 def italics(text: str, escape_formatting: bool = True) -> str:
@@ -141,8 +176,7 @@ def italics(text: str, escape_formatting: bool = True) -> str:
         The marked up text.
 
     """
-    text = escape(text, formatting=escape_formatting)
-    return "*{}*".format(text)
+    return f"*{escape(text, formatting=escape_formatting)}*"
 
 
 def spoiler(text: str, escape_formatting: bool = True) -> str:
@@ -163,8 +197,7 @@ def spoiler(text: str, escape_formatting: bool = True) -> str:
         The marked up text.
 
     """
-    text = escape(text, formatting=escape_formatting)
-    return "||{}||".format(text)
+    return f"||{escape(text, formatting=escape_formatting)}||"
 
 
 def bordered(*columns: Sequence[str], ascii_border: bool = False) -> str:
@@ -323,8 +356,7 @@ def strikethrough(text: str, escape_formatting: bool = True) -> str:
         The marked up text.
 
     """
-    text = escape(text, formatting=escape_formatting)
-    return "~~{}~~".format(text)
+    return f"~~{escape(text, formatting=escape_formatting)}~~"
 
 
 def underline(text: str, escape_formatting: bool = True) -> str:
@@ -345,8 +377,7 @@ def underline(text: str, escape_formatting: bool = True) -> str:
         The marked up text.
 
     """
-    text = escape(text, formatting=escape_formatting)
-    return "__{}__".format(text)
+    return f"__{escape(text, formatting=escape_formatting)}__"
 
 
 def quote(text: str) -> str:
